@@ -5,9 +5,10 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
+$VERSION =~ tr/_//d;
 
-use Carp qw(verbose); # makes carp() cluck and croak() confess
+use Carp qw(verbose);    # makes carp() cluck and croak() confess
 
 sub _warn {
   if ($_[-1] =~ /\n$/s) {
@@ -32,7 +33,8 @@ my %OLD_SIG;
 
 BEGIN {
   @OLD_SIG{qw(__DIE__ __WARN__)} = @SIG{qw(__DIE__ __WARN__)};
-  $SIG{__DIE__} = \&_die;
+
+  $SIG{__DIE__}  = \&_die;
   $SIG{__WARN__} = \&_warn;
 }
 
@@ -41,7 +43,6 @@ END {
 }
 
 1;
-__END__
 
 =encoding utf8
 
@@ -53,8 +54,7 @@ Carp::Always - Warns and dies noisily with stack backtraces
 
   use Carp::Always;
 
-makes every C<warn()> and C<die()> complains loudly in the calling package 
-and elsewhere. More often used on the command line:
+Often used on the command line:
 
   perl -MCarp::Always script.pl
 
@@ -80,15 +80,14 @@ looks:
           main::f('undef') called at -e line 2
           main::g() called at -e line 2
 
-In the implementation, the C<Carp> module does
+In the implementation, the L<Carp> module does
 the heavy work, through C<longmess()>. The
 actual implementation sets the signal hooks
 C<$SIG{__WARN__}> and C<$SIG{__DIE__}> to
 emit the stack backtraces.
 
-Oh, by the way, C<carp> and C<croak> when requiring/using
-the C<Carp> module are also made verbose, behaving
-like C<cluck> and C<confess>, respectively.
+Also, all uses of C<carp> and C<croak> are made verbose,
+behaving like C<cluck> and C<confess>.
 
 =head2 EXPORT
 
@@ -101,64 +100,46 @@ of L<Acme::JavaTrace> by Sébastien Aperghis-Tramoni.
 Sébastien also has a newer module called
 L<Devel::SimpleTrace> with the same code and fewer flame
 comments on docs. The pruning of the uselessly long
-docs of this module were prodded by Michael Schwern.
+docs of this module was prodded by Michael Schwern.
 
 Schwern and others told me "the module name stinked" -
 it was called C<Carp::Indeed>. After thinking long
-and not getting nowhere, I went with nuffin's suggestion
+and getting nowhere, I went with nuffin's suggestion
 and now it is called C<Carp::Always>. 
-C<Carp::Indeed> which is now deprecate
-lives in its own distribution (which won't go anywhere
-but will stay there as a redirection to this module).
 
 =head1 SEE ALSO
 
-=over 4
-
-=item *
-
 L<Carp>
 
-=item *
-
 L<Acme::JavaTrace> and L<Devel::SimpleTrace>
 
-=item *
-
 L<Carp::Always::Color>
 
-=item *
-
 L<Carp::Source::Always>
 
-=back
-
-Please report bugs via CPAN RT 
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Carp-Always.
+L<Devel::Confess>
 
 =head1 BUGS
 
-Every (un)deserving module has its own pet bugs.
-
 =over 4
 
 =item *
 
 This module does not play well with other modules which fusses
-around with C<warn>, C<die>, C<$SIG{'__WARN__'}>,
-C<$SIG{'__DIE__'}>.
+around with C<warn>, C<die>, C<$SIG{__WARN__}>,
+C<$SIG{__DIE__}>.
 
 =item *
 
 Test scripts are good. I should write more of these.
 
-=item *
-
-I don't know if this module name is still a bug as it was
-at the time of C<Carp::Indeed>.
-
 =back
 
+Please report bugs via GitHub
+L<https://github.com/aferreira/cpan-Carp-Always/issues>
+
+Backlog in CPAN RT: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Carp-Always>
+
 =head1 AUTHOR
 
 Adriano Ferreira, E<lt>ferreira@cpan.orgE<gt>
